# noglobal-magic

Magic command for prohibit using global variables in Jupyter Notebook.

## Installation

Make sure you've this `noglobal-magic` (And the Python package `pyflakes`).

```shell
pip install noglobal-magic
```

## How to use

In a cell on Jupyter Notebook, load and activate this extension:

```notebook
%load_ext noglobal_magic
%no_global
```

You've ready to enjoy coding.

Let's see how it works:
